@@ -1,6 +1,8 @@
 #include "hdy-demo-window.h"
 
 #include <glib/gi18n.h>
+#include "hdy-flap-demo-window.h"
+#include "hdy-tab-view-demo-window.h"
 #include "hdy-view-switcher-demo-window.h"
 
 struct _HdyDemoWindow
@@ -10,7 +12,8 @@ struct _HdyDemoWindow
   HdyLeaflet *content_box;
   GtkStack *header_revealer;
   GtkStack *header_stack;
-  GtkImage *theme_variant_image;
+  GtkWidget *color_scheme_button;
+  GtkImage *color_scheme_image;
   GtkStackSidebar *sidebar;
   GtkStack *stack;
   HdyComboRow *leaflet_transition_row;
@@ -21,35 +24,40 @@ struct _HdyDemoWindow
   HdyKeypad *keypad;
   HdySearchBar *search_bar;
   GtkEntry *search_entry;
-  GtkListBox *column_listbox;
   GtkListBox *lists_listbox;
   HdyComboRow *combo_row;
   HdyComboRow *enum_combo_row;
   HdyCarousel *carousel;
+  GtkBox *carousel_box;
   GtkListBox *carousel_listbox;
+  GtkStack *carousel_indicators_stack;
   HdyComboRow *carousel_orientation_row;
-  HdyComboRow *carousel_indicator_style_row;
+  HdyComboRow *carousel_indicators_row;
+  GListStore *carousel_indicators_model;
   HdyAvatar *avatar;
+  GtkEntry *avatar_text;
   GtkFileChooserButton *avatar_filechooser;
+  GtkListBox *avatar_contacts;
 };
 
 G_DEFINE_TYPE (HdyDemoWindow, hdy_demo_window, HDY_TYPE_APPLICATION_WINDOW)
 
 static void
-theme_variant_button_clicked_cb (HdyDemoWindow *self)
+color_scheme_button_clicked_cb (HdyDemoWindow *self)
 {
-  GtkSettings *settings = gtk_settings_get_default ();
-  gboolean prefer_dark_theme;
+  HdyStyleManager *manager = hdy_style_manager_get_default ();
 
-  g_object_get (settings, "gtk-application-prefer-dark-theme", &prefer_dark_theme, NULL);
-  g_object_set (settings, "gtk-application-prefer-dark-theme", !prefer_dark_theme, NULL);
+  if (hdy_style_manager_get_dark (manager))
+    hdy_style_manager_set_color_scheme (manager, HDY_COLOR_SCHEME_FORCE_LIGHT);
+  else
+    hdy_style_manager_set_color_scheme (manager, HDY_COLOR_SCHEME_FORCE_DARK);
 }
 
 static gboolean
-prefer_dark_theme_to_icon_name_cb (GBinding     *binding,
-                                   const GValue *from_value,
-                                   GValue       *to_value,
-                                   gpointer      user_data)
+dark_to_icon_name_cb (GBinding     *binding,
+                      const GValue *from_value,
+                      GValue       *to_value,
+                      gpointer      user_data)
 {
   g_value_set_string (to_value,
                       g_value_get_boolean (from_value) ? "light-mode-symbolic" :
@@ -59,17 +67,26 @@ prefer_dark_theme_to_icon_name_cb (GBinding     *binding,
 }
 
 static gboolean
-hdy_demo_window_key_pressed_cb (GtkWidget     *sender,
-                                GdkEvent      *event,
-                                HdyDemoWindow *self)
+key_pressed_cb (GtkWidget     *sender,
+                GdkEvent      *event,
+                HdyDemoWindow *self)
 {
   GdkModifierType default_modifiers = gtk_accelerator_get_default_mod_mask ();
   guint keyval;
   GdkModifierType state;
+  GdkKeymap *keymap;
+  GdkEventKey *key_event = (GdkEventKey *) event;
 
-  gdk_event_get_keyval (event, &keyval);
   gdk_event_get_state (event, &state);
 
+  keymap = gdk_keymap_get_for_display (gtk_widget_get_display (sender));
+
+  gdk_keymap_translate_keyboard_state (keymap,
+                                       key_event->hardware_keycode,
+                                       state,
+                                       key_event->group,
+                                       &keyval, NULL, NULL, NULL);
+
   if ((keyval == GDK_KEY_q || keyval == GDK_KEY_Q) &&
       (state & default_modifiers) == GDK_CONTROL_MASK) {
     gtk_widget_destroy (GTK_WIDGET (self));
@@ -80,61 +97,37 @@ hdy_demo_window_key_pressed_cb (GtkWidget     *sender,
   return FALSE;
 }
 
-static void
-update_leaflet_swipe (HdyDemoWindow *self)
-{
-  gboolean first_page = (hdy_carousel_get_position (self->carousel) <= 0);
-  gboolean carousel_visible =
-    (gtk_stack_get_visible_child (self->stack) == GTK_WIDGET (self->carousel));
-
-  hdy_leaflet_set_can_swipe_back (self->content_box,
-                                  !carousel_visible || first_page);
-}
-
 static void
 update (HdyDemoWindow *self)
 {
   const gchar *header_bar_name = "default";
-  gboolean leaflet_can_swipe_back = TRUE;
 
-  if (g_strcmp0 (gtk_stack_get_visible_child_name (self->stack), "deck") == 0) {
-    header_bar_name = "deck";
-    leaflet_can_swipe_back = g_strcmp0 (hdy_deck_get_visible_child_name (self->content_deck), "sub") != 0;
-  } else if (g_strcmp0 (gtk_stack_get_visible_child_name (self->stack), "search-bar") == 0) {
+  if (g_strcmp0 (gtk_stack_get_visible_child_name (self->stack), "search-bar") == 0)
     header_bar_name = "search-bar";
-  }
 
   gtk_stack_set_visible_child_name (self->header_stack, header_bar_name);
-  hdy_leaflet_set_can_swipe_back (self->content_box, leaflet_can_swipe_back);
 }
 
 static void
-hdy_demo_window_notify_deck_visible_child_cb (HdyDemoWindow *self)
-{
-  update (self);
-}
-
-static void
-hdy_demo_window_notify_visible_child_cb (GObject       *sender,
-                                         GParamSpec    *pspec,
-                                         HdyDemoWindow *self)
+notify_visible_child_cb (GObject       *sender,
+                         GParamSpec    *pspec,
+                         HdyDemoWindow *self)
 {
   update (self);
 
   hdy_leaflet_navigate (self->content_box, HDY_NAVIGATION_DIRECTION_FORWARD);
-  update_leaflet_swipe (self);
 }
 
 static void
-hdy_demo_window_back_clicked_cb (GtkWidget     *sender,
-                                 HdyDemoWindow *self)
+back_clicked_cb (GtkWidget     *sender,
+                 HdyDemoWindow *self)
 {
   hdy_leaflet_navigate (self->content_box, HDY_NAVIGATION_DIRECTION_BACK);
 }
 
 static void
-hdy_demo_window_deck_back_clicked_cb (GtkWidget     *sender,
-                                      HdyDemoWindow *self)
+deck_back_clicked_cb (GtkWidget     *sender,
+                      HdyDemoWindow *self)
 {
   hdy_deck_navigate (self->content_deck, HDY_NAVIGATION_DIRECTION_BACK);
 }
@@ -146,14 +139,12 @@ leaflet_transition_name (HdyEnumValueObject *value,
   g_return_val_if_fail (HDY_IS_ENUM_VALUE_OBJECT (value), NULL);
 
   switch (hdy_enum_value_object_get_value (value)) {
-  case HDY_LEAFLET_TRANSITION_TYPE_NONE:
-    return g_strdup (_("None"));
-  case HDY_LEAFLET_TRANSITION_TYPE_SLIDE:
-    return g_strdup (_("Slide"));
   case HDY_LEAFLET_TRANSITION_TYPE_OVER:
     return g_strdup (_("Over"));
   case HDY_LEAFLET_TRANSITION_TYPE_UNDER:
     return g_strdup (_("Under"));
+  case HDY_LEAFLET_TRANSITION_TYPE_SLIDE:
+    return g_strdup (_("Slide"));
   default:
     return NULL;
   }
@@ -179,14 +170,12 @@ deck_transition_name (HdyEnumValueObject *value,
   g_return_val_if_fail (HDY_IS_ENUM_VALUE_OBJECT (value), NULL);
 
   switch (hdy_enum_value_object_get_value (value)) {
-  case HDY_DECK_TRANSITION_TYPE_NONE:
-    return g_strdup (_("None"));
-  case HDY_DECK_TRANSITION_TYPE_SLIDE:
-    return g_strdup (_("Slide"));
   case HDY_DECK_TRANSITION_TYPE_OVER:
     return g_strdup (_("Over"));
   case HDY_DECK_TRANSITION_TYPE_UNDER:
     return g_strdup (_("Under"));
+  case HDY_DECK_TRANSITION_TYPE_SLIDE:
+    return g_strdup (_("Slide"));
   default:
     return NULL;
   }
@@ -239,64 +228,56 @@ carousel_orientation_name (HdyEnumValueObject *value,
   }
 }
 
-static void
-notify_carousel_position_cb (GObject       *sender,
-                             GParamSpec    *pspec,
-                             HdyDemoWindow *self)
-{
-  update_leaflet_swipe (self);
-}
-
 static void
 notify_carousel_orientation_cb (GObject       *sender,
                                 GParamSpec    *pspec,
                                 HdyDemoWindow *self)
 {
   HdyComboRow *row = HDY_COMBO_ROW (sender);
-  gboolean horizontal;
 
   g_assert (HDY_IS_COMBO_ROW (row));
   g_assert (HDY_IS_DEMO_WINDOW (self));
 
-  horizontal = (hdy_combo_row_get_selected_index (row) == GTK_ORIENTATION_HORIZONTAL);
-  g_object_set (self->carousel,
-                "orientation", hdy_combo_row_get_selected_index (row),
-                "margin-top", horizontal ? 6 : 0,
-                "margin-bottom", horizontal ? 6 : 0,
-                "margin-left", horizontal ? 0 : 6,
-                "margin-right", horizontal ? 0 : 6,
-                NULL);
+  gtk_orientable_set_orientation (GTK_ORIENTABLE (self->carousel_box),
+                                  1 - hdy_combo_row_get_selected_index (row));
+  gtk_orientable_set_orientation (GTK_ORIENTABLE (self->carousel),
+                                  hdy_combo_row_get_selected_index (row));
 }
 
 static gchar *
-carousel_indicator_style_name (HdyEnumValueObject *value,
-                               gpointer            user_data)
+carousel_indicators_name (HdyValueObject *value)
 {
-  g_return_val_if_fail (HDY_IS_ENUM_VALUE_OBJECT (value), NULL);
+  const gchar *style;
 
-  switch (hdy_enum_value_object_get_value (value)) {
-  case HDY_CAROUSEL_INDICATOR_STYLE_NONE:
-    return g_strdup (_("None"));
-  case HDY_CAROUSEL_INDICATOR_STYLE_DOTS:
+  g_assert (HDY_IS_VALUE_OBJECT (value));
+
+  style = hdy_value_object_get_string (value);
+
+  if (!g_strcmp0 (style, "dots"))
     return g_strdup (_("Dots"));
-  case HDY_CAROUSEL_INDICATOR_STYLE_LINES:
+
+  if (!g_strcmp0 (style, "lines"))
     return g_strdup (_("Lines"));
-  default:
-    return NULL;
-  }
+
+  return NULL;
 }
 
 static void
-notify_carousel_indicator_style_cb (GObject       *sender,
-                                    GParamSpec    *pspec,
-                                    HdyDemoWindow *self)
+notify_carousel_indicators_cb (GObject       *sender,
+                               GParamSpec    *pspec,
+                               HdyDemoWindow *self)
 {
   HdyComboRow *row = HDY_COMBO_ROW (sender);
+  g_autoptr (HdyValueObject) obj = NULL;
 
   g_assert (HDY_IS_COMBO_ROW (row));
   g_assert (HDY_IS_DEMO_WINDOW (self));
 
-  hdy_carousel_set_indicator_style (self->carousel, hdy_combo_row_get_selected_index (row));
+  obj = g_list_model_get_item (G_LIST_MODEL (self->carousel_indicators_model),
+                               hdy_combo_row_get_selected_index (row));
+
+  gtk_stack_set_visible_child_name (self->carousel_indicators_stack,
+                                    hdy_value_object_get_string (obj));
 }
 
 static void
@@ -326,43 +307,155 @@ avatar_file_remove_cb (HdyDemoWindow *self)
   file = gtk_file_chooser_get_filename (GTK_FILE_CHOOSER (self->avatar_filechooser));
   if (file)
     gtk_file_chooser_unselect_filename (GTK_FILE_CHOOSER (self->avatar_filechooser), file);
-  hdy_avatar_set_image_load_func (self->avatar, NULL, NULL, NULL);
-}
 
-static GdkPixbuf *
-avatar_load_file (gint size, HdyDemoWindow *self)
-{
-  g_autoptr (GError) error = NULL;
-  g_autoptr (GdkPixbuf) pixbuf = NULL;
-  g_autofree gchar *file = NULL;
-  gint width, height;
-
-  g_assert (HDY_IS_DEMO_WINDOW (self));
-
-  file = gtk_file_chooser_get_filename (GTK_FILE_CHOOSER (self->avatar_filechooser));
-
-  gdk_pixbuf_get_file_info (file, &width, &height);
-
-  pixbuf = gdk_pixbuf_new_from_file_at_scale (file,
-                                            (width <= height) ? size : -1,
-                                            (width >= height) ? size : -1,
-                                            TRUE,
-                                            &error);
-  if (error != NULL) {
-    g_critical ("Failed to create pixbuf from file: %s", error->message);
-
-    return NULL;
-  }
-
-  return g_steal_pointer (&pixbuf);
+  hdy_avatar_set_loadable_icon (self->avatar, NULL);
 }
 
 static void
 avatar_file_set_cb (HdyDemoWindow *self)
 {
+  g_autoptr (GFile) file = NULL;
+  g_autoptr (GIcon) icon = NULL;
+
   g_assert (HDY_IS_DEMO_WINDOW (self));
 
-  hdy_avatar_set_image_load_func (self->avatar, (HdyAvatarImageLoadFunc) avatar_load_file, self, NULL);
+  file = gtk_file_chooser_get_file (GTK_FILE_CHOOSER (self->avatar_filechooser));
+  icon = g_file_icon_new (file);
+  hdy_avatar_set_loadable_icon (self->avatar, G_LOADABLE_ICON (icon));
+}
+
+static void
+file_chooser_response_cb (HdyDemoWindow  *self,
+                          gint            response_id,
+                          GtkFileChooser *chooser)
+{
+  if (response_id == GTK_RESPONSE_ACCEPT) {
+    g_autofree gchar *filename = gtk_file_chooser_get_filename (chooser);
+    g_autoptr (GdkPixbuf) pixbuf =
+      hdy_avatar_draw_to_pixbuf (self->avatar,
+                                 hdy_avatar_get_size (self->avatar),
+                                 gtk_widget_get_scale_factor (GTK_WIDGET (self)));
+
+    if (pixbuf != NULL)
+      gdk_pixbuf_save (pixbuf, filename, "png", NULL, NULL);
+  }
+
+  g_object_unref (chooser);
+}
+
+static void
+avatar_save_to_file_cb (HdyDemoWindow *self)
+{
+  GtkFileChooserNative *chooser = NULL;
+
+  g_assert (HDY_IS_DEMO_WINDOW (self));
+
+  chooser = gtk_file_chooser_native_new (_("Save Avatar"),
+                                         GTK_WINDOW (self),
+                                         GTK_FILE_CHOOSER_ACTION_SAVE,
+                                         _("_Save"),
+                                         _("_Cancel"));
+
+  gtk_file_chooser_set_do_overwrite_confirmation (GTK_FILE_CHOOSER (chooser), TRUE);
+  g_signal_connect_swapped (chooser, "response", G_CALLBACK (file_chooser_response_cb), self);
+
+  gtk_native_dialog_show (GTK_NATIVE_DIALOG (chooser));
+}
+
+static gchar *
+avatar_new_random_name (void)
+{
+  static const char *first_names[] = {
+    "Adam",
+    "Adrian",
+    "Anna",
+    "Charlotte",
+    "Frédérique",
+    "Ilaria",
+    "Jakub",
+    "Jennyfer",
+    "Julia",
+    "Justin",
+    "Mario",
+    "Miriam",
+    "Mohamed",
+    "Nourimane",
+    "Owen",
+    "Peter",
+    "Petra",
+    "Rachid",
+    "Rebecca",
+    "Sarah",
+    "Thibault",
+    "Wolfgang",
+  };
+  static const char *last_names[] = {
+    "Bailey",
+    "Berat",
+    "Chen",
+    "Farquharson",
+    "Ferber",
+    "Franco",
+    "Galinier",
+    "Han",
+    "Lawrence",
+    "Lepied",
+    "Lopez",
+    "Mariotti",
+    "Rossi",
+    "Urasawa",
+    "Zwickelman",
+  };
+
+  return g_strdup_printf ("%s %s",
+                          first_names[g_random_int_range (0, G_N_ELEMENTS (first_names))],
+                          last_names[g_random_int_range (0, G_N_ELEMENTS (last_names))]);
+}
+
+static void
+avatar_update_contacts (HdyDemoWindow *self)
+{
+  g_autoptr (GList) children = gtk_container_get_children (GTK_CONTAINER (self->avatar_contacts));
+
+  for (GList *child = children; child; child = child->next)
+    gtk_container_remove (GTK_CONTAINER (self->avatar_contacts), child->data);
+
+  for (int i = 0; i < 30; i++) {
+    g_autofree gchar *name = avatar_new_random_name ();
+    GtkWidget *contact = hdy_action_row_new ();
+    GtkWidget *avatar = hdy_avatar_new (40, name, TRUE);
+
+    gtk_widget_show (contact);
+    gtk_widget_show (avatar);
+
+    gtk_widget_set_margin_top (avatar, 12);
+    gtk_widget_set_margin_bottom (avatar, 12);
+
+    hdy_preferences_row_set_title (HDY_PREFERENCES_ROW (contact), name);
+    hdy_action_row_add_prefix (HDY_ACTION_ROW (contact), avatar);
+    gtk_container_add (GTK_CONTAINER (self->avatar_contacts), contact);
+  }
+}
+
+static void
+flap_demo_clicked_cb (GtkButton     *btn,
+                      HdyDemoWindow *self)
+{
+  HdyFlapDemoWindow *window = hdy_flap_demo_window_new ();
+
+  gtk_window_set_transient_for (GTK_WINDOW (window), GTK_WINDOW (self));
+  gtk_widget_show (GTK_WIDGET (window));
+}
+
+static void
+tab_view_demo_clicked_cb (GtkButton     *btn,
+                          HdyDemoWindow *self)
+{
+  HdyTabViewDemoWindow *window = hdy_tab_view_demo_window_new ();
+
+  hdy_tab_view_demo_window_prepopulate (window);
+
+  gtk_window_present (GTK_WINDOW (window));
 }
 
 static void
@@ -388,7 +481,8 @@ hdy_demo_window_class_init (HdyDemoWindowClass *klass)
   gtk_widget_class_bind_template_child (widget_class, HdyDemoWindow, content_box);
   gtk_widget_class_bind_template_child (widget_class, HdyDemoWindow, header_revealer);
   gtk_widget_class_bind_template_child (widget_class, HdyDemoWindow, header_stack);
-  gtk_widget_class_bind_template_child (widget_class, HdyDemoWindow, theme_variant_image);
+  gtk_widget_class_bind_template_child (widget_class, HdyDemoWindow, color_scheme_button);
+  gtk_widget_class_bind_template_child (widget_class, HdyDemoWindow, color_scheme_image);
   gtk_widget_class_bind_template_child (widget_class, HdyDemoWindow, sidebar);
   gtk_widget_class_bind_template_child (widget_class, HdyDemoWindow, stack);
   gtk_widget_class_bind_template_child (widget_class, HdyDemoWindow, leaflet_transition_row);
@@ -399,38 +493,42 @@ hdy_demo_window_class_init (HdyDemoWindowClass *klass)
   gtk_widget_class_bind_template_child (widget_class, HdyDemoWindow, keypad);
   gtk_widget_class_bind_template_child (widget_class, HdyDemoWindow, search_bar);
   gtk_widget_class_bind_template_child (widget_class, HdyDemoWindow, search_entry);
-  gtk_widget_class_bind_template_child (widget_class, HdyDemoWindow, column_listbox);
   gtk_widget_class_bind_template_child (widget_class, HdyDemoWindow, lists_listbox);
   gtk_widget_class_bind_template_child (widget_class, HdyDemoWindow, combo_row);
   gtk_widget_class_bind_template_child (widget_class, HdyDemoWindow, enum_combo_row);
   gtk_widget_class_bind_template_child (widget_class, HdyDemoWindow, carousel);
+  gtk_widget_class_bind_template_child (widget_class, HdyDemoWindow, carousel_box);
   gtk_widget_class_bind_template_child (widget_class, HdyDemoWindow, carousel_listbox);
+  gtk_widget_class_bind_template_child (widget_class, HdyDemoWindow, carousel_indicators_stack);
   gtk_widget_class_bind_template_child (widget_class, HdyDemoWindow, carousel_orientation_row);
-  gtk_widget_class_bind_template_child (widget_class, HdyDemoWindow, carousel_indicator_style_row);
+  gtk_widget_class_bind_template_child (widget_class, HdyDemoWindow, carousel_indicators_row);
   gtk_widget_class_bind_template_child (widget_class, HdyDemoWindow, avatar);
+  gtk_widget_class_bind_template_child (widget_class, HdyDemoWindow, avatar_text);
   gtk_widget_class_bind_template_child (widget_class, HdyDemoWindow, avatar_filechooser);
-  gtk_widget_class_bind_template_callback_full (widget_class, "key_pressed_cb", G_CALLBACK(hdy_demo_window_key_pressed_cb));
-  gtk_widget_class_bind_template_callback_full (widget_class, "notify_visible_child_cb", G_CALLBACK(hdy_demo_window_notify_visible_child_cb));
-  gtk_widget_class_bind_template_callback_full (widget_class, "notify_deck_visible_child_cb", G_CALLBACK(hdy_demo_window_notify_deck_visible_child_cb));
-  gtk_widget_class_bind_template_callback_full (widget_class, "back_clicked_cb", G_CALLBACK(hdy_demo_window_back_clicked_cb));
-  gtk_widget_class_bind_template_callback_full (widget_class, "deck_back_clicked_cb", G_CALLBACK(hdy_demo_window_deck_back_clicked_cb));
-  gtk_widget_class_bind_template_callback_full (widget_class, "notify_leaflet_transition_cb", G_CALLBACK(notify_leaflet_transition_cb));
-  gtk_widget_class_bind_template_callback_full (widget_class, "notify_deck_transition_cb", G_CALLBACK(notify_deck_transition_cb));
-  gtk_widget_class_bind_template_callback_full (widget_class, "deck_go_next_row_activated_cb", G_CALLBACK(deck_go_next_row_activated_cb));
-  gtk_widget_class_bind_template_callback_full (widget_class, "theme_variant_button_clicked_cb", G_CALLBACK(theme_variant_button_clicked_cb));
-  gtk_widget_class_bind_template_callback_full (widget_class, "view_switcher_demo_clicked_cb", G_CALLBACK(view_switcher_demo_clicked_cb));
-  gtk_widget_class_bind_template_callback_full (widget_class, "notify_carousel_position_cb", G_CALLBACK(notify_carousel_position_cb));
-  gtk_widget_class_bind_template_callback_full (widget_class, "notify_carousel_orientation_cb", G_CALLBACK(notify_carousel_orientation_cb));
-  gtk_widget_class_bind_template_callback_full (widget_class, "notify_carousel_indicator_style_cb", G_CALLBACK(notify_carousel_indicator_style_cb));
-  gtk_widget_class_bind_template_callback_full (widget_class, "carousel_return_clicked_cb", G_CALLBACK(carousel_return_clicked_cb));
-  gtk_widget_class_bind_template_callback_full (widget_class, "avatar_file_remove_cb", G_CALLBACK(avatar_file_remove_cb));
-  gtk_widget_class_bind_template_callback_full (widget_class, "avatar_file_set_cb", G_CALLBACK(avatar_file_set_cb));
+  gtk_widget_class_bind_template_child (widget_class, HdyDemoWindow, avatar_contacts);
+  gtk_widget_class_bind_template_callback (widget_class, key_pressed_cb);
+  gtk_widget_class_bind_template_callback (widget_class, notify_visible_child_cb);
+  gtk_widget_class_bind_template_callback (widget_class, back_clicked_cb);
+  gtk_widget_class_bind_template_callback (widget_class, deck_back_clicked_cb);
+  gtk_widget_class_bind_template_callback (widget_class, notify_leaflet_transition_cb);
+  gtk_widget_class_bind_template_callback (widget_class, notify_deck_transition_cb);
+  gtk_widget_class_bind_template_callback (widget_class, deck_go_next_row_activated_cb);
+  gtk_widget_class_bind_template_callback (widget_class, color_scheme_button_clicked_cb);
+  gtk_widget_class_bind_template_callback (widget_class, view_switcher_demo_clicked_cb);
+  gtk_widget_class_bind_template_callback (widget_class, notify_carousel_orientation_cb);
+  gtk_widget_class_bind_template_callback (widget_class, notify_carousel_indicators_cb);
+  gtk_widget_class_bind_template_callback (widget_class, carousel_return_clicked_cb);
+  gtk_widget_class_bind_template_callback (widget_class, avatar_file_remove_cb);
+  gtk_widget_class_bind_template_callback (widget_class, avatar_file_set_cb);
+  gtk_widget_class_bind_template_callback (widget_class, avatar_save_to_file_cb);
+  gtk_widget_class_bind_template_callback (widget_class, flap_demo_clicked_cb);
+  gtk_widget_class_bind_template_callback (widget_class, tab_view_demo_clicked_cb);
 }
 
 static void
 lists_page_init (HdyDemoWindow *self)
 {
-  GListStore *list_store;
+  g_autoptr (GListStore) list_store = NULL;
   HdyValueObject *obj;
 
   list_store = g_list_store_new (HDY_TYPE_VALUE_OBJECT);
@@ -453,21 +551,64 @@ lists_page_init (HdyDemoWindow *self)
   update (self);
 }
 
+static void
+carousel_page_init (HdyDemoWindow *self)
+{
+  g_autoptr (GListStore) list_store = NULL;
+  HdyValueObject *obj;
+
+  hdy_combo_row_set_for_enum (self->carousel_orientation_row,
+                              GTK_TYPE_ORIENTATION,
+                              carousel_orientation_name,
+                              NULL,
+                              NULL);
+
+  list_store = g_list_store_new (HDY_TYPE_VALUE_OBJECT);
+
+  obj = hdy_value_object_new_string ("dots");
+  g_list_store_insert (list_store, 0, obj);
+  g_clear_object (&obj);
+
+  obj = hdy_value_object_new_string ("lines");
+  g_list_store_insert (list_store, 1, obj);
+  g_clear_object (&obj);
+
+  self->carousel_indicators_model = list_store;
+  hdy_combo_row_bind_name_model (self->carousel_indicators_row,
+                                 G_LIST_MODEL (list_store),
+                                 (HdyComboRowGetNameFunc) carousel_indicators_name,
+                                 NULL,
+                                 NULL);
+}
+
+static void
+avatar_page_init (HdyDemoWindow *self)
+{
+  g_autofree gchar *name = avatar_new_random_name ();
+
+  gtk_entry_set_text (self->avatar_text, name);
+
+  avatar_update_contacts (self);
+}
+
 static void
 hdy_demo_window_init (HdyDemoWindow *self)
 {
-  GtkSettings *settings = gtk_settings_get_default ();
+  HdyStyleManager *manager = hdy_style_manager_get_default ();
 
   gtk_widget_init_template (GTK_WIDGET (self));
 
-  g_object_bind_property_full (settings, "gtk-application-prefer-dark-theme",
-                               self->theme_variant_image, "icon-name",
+  g_object_bind_property_full (manager, "dark",
+                               self->color_scheme_image, "icon-name",
                                G_BINDING_SYNC_CREATE,
-                               prefer_dark_theme_to_icon_name_cb,
+                               dark_to_icon_name_cb,
                                NULL,
                                NULL,
                                NULL);
 
+  gtk_widget_set_visible (self->color_scheme_button,
+                          !hdy_style_manager_get_system_supports_color_schemes (manager));
+
   hdy_combo_row_set_for_enum (self->leaflet_transition_row, HDY_TYPE_LEAFLET_TRANSITION_TYPE, leaflet_transition_name, NULL, NULL);
   hdy_combo_row_set_selected_index (self->leaflet_transition_row, HDY_LEAFLET_TRANSITION_TYPE_OVER);
 
@@ -475,10 +616,8 @@ hdy_demo_window_init (HdyDemoWindow *self)
   hdy_combo_row_set_selected_index (self->deck_transition_row, HDY_DECK_TRANSITION_TYPE_OVER);
 
   lists_page_init (self);
-
-  hdy_combo_row_set_for_enum (self->carousel_orientation_row, GTK_TYPE_ORIENTATION, carousel_orientation_name, NULL, NULL);
-  hdy_combo_row_set_for_enum (self->carousel_indicator_style_row, HDY_TYPE_CAROUSEL_INDICATOR_STYLE, carousel_indicator_style_name, NULL, NULL);
-  hdy_combo_row_set_selected_index (self->carousel_indicator_style_row, HDY_CAROUSEL_INDICATOR_STYLE_DOTS);
+  carousel_page_init (self);
+  avatar_page_init (self);
 
   hdy_leaflet_set_visible_child_name (self->content_box, "content");
 }
