@@ -1,7 +1,7 @@
 /*
  * Copyright (C) 2018 Purism SPC
  *
- * SPDX-License-Identifier: LGPL-2.1+
+ * SPDX-License-Identifier: LGPL-2.1-or-later
  */
 #pragma once
 
@@ -9,7 +9,7 @@
 #error "Only <handy.h> can be included directly."
 #endif
 
-#include <glib.h>
+#include "hdy-main.h"
 
 G_BEGIN_DECLS
 
