@@ -2,7 +2,7 @@
  * Copyright (C) 2019 Zander Brown <zbrown@gnome.org>
  * Copyright (C) 2019 Purism SPC
  *
- * SPDX-License-Identifier: LGPL-2.1+
+ * SPDX-License-Identifier: LGPL-2.1-or-later
  */
 
 #include "config.h"
@@ -12,23 +12,26 @@
 #include "hdy-squeezer.h"
 
 /**
- * SECTION:hdy-view-switcher-title
- * @short_description: A view switcher title.
- * @title: HdyViewSwitcherTitle
- * @See_also: #HdyHeaderBar, #HdyViewSwitcher, #HdyViewSwitcherBar
+ * HdyViewSwitcherTitle:
  *
- * A widget letting you switch between multiple views offered by a #GtkStack,
- * via an #HdyViewSwitcher. It is designed to be used as the title widget of a
- * #HdyHeaderBar, and will display the window's title when the window is too
- * narrow to fit the view switcher e.g. on mobile phones, or if there are less
- * than two views.
+ * A view switcher title.
  *
- * You can conveniently bind the #HdyViewSwitcherBar:reveal property to
- * #HdyViewSwitcherTitle:title-visible to automatically reveal the view switcher
- * bar when the title label is displayed in place of the view switcher.
+ * A widget letting you switch between multiple views contained by a
+ * [class@Gtk.Stack], via an [class@ViewSwitcher].
  *
- * An example of the UI definition for a common use case:
- * |[
+ * It is designed to be used as the title widget of a [class@HeaderBar], and
+ * will display the window's title when the window is too narrow to fit the view
+ * switcher e.g. on mobile phones, or if there are less than two views.
+ *
+ * `HdyViewSwitcherTitle` is intended to be used together with
+ * [class@ViewSwitcherBar].
+ *
+ * A common use case is to bind the [property@ViewSwitcherBar:reveal] property
+ * to [property@ViewSwitcherTitle:title-visible] to automatically reveal the
+ * view switcher bar when the title label is displayed in place of the view
+ * switcher, as follows:
+ *
+ * ```xml
  * <object class="GtkWindow"/>
  *   <child type="titlebar">
  *     <object class="HdyHeaderBar">
@@ -58,11 +61,11 @@
  *     </object>
  *   </child>
  * </object>
- * ]|
+ * ```
  *
- * # CSS nodes
+ * ## CSS nodes
  *
- * #HdyViewSwitcherTitle has a single CSS node with name viewswitchertitle.
+ * `HdyViewSwitcherTitle` has a single CSS node with name `viewswitchertitle`.
  *
  * Since: 1.0
  */
@@ -70,7 +73,6 @@
 enum {
   PROP_0,
   PROP_POLICY,
-  PROP_ICON_SIZE,
   PROP_STACK,
   PROP_TITLE,
   PROP_SUBTITLE,
@@ -79,7 +81,10 @@ enum {
   LAST_PROP,
 };
 
-typedef struct {
+struct _HdyViewSwitcherTitle
+{
+  GtkBin parent_instance;
+
   HdySqueezer *squeezer;
   GtkLabel *subtitle_label;
   GtkBox *title_box;
@@ -87,20 +92,18 @@ typedef struct {
   HdyViewSwitcher *view_switcher;
 
   gboolean view_switcher_enabled;
-} HdyViewSwitcherTitlePrivate;
+};
 
 static GParamSpec *props[LAST_PROP];
 
-G_DEFINE_TYPE_WITH_CODE (HdyViewSwitcherTitle, hdy_view_switcher_title, GTK_TYPE_BIN,
-                         G_ADD_PRIVATE (HdyViewSwitcherTitle))
+G_DEFINE_TYPE (HdyViewSwitcherTitle, hdy_view_switcher_title, GTK_TYPE_BIN)
 
 static void
 update_subtitle_label (HdyViewSwitcherTitle *self)
 {
-  HdyViewSwitcherTitlePrivate *priv = hdy_view_switcher_title_get_instance_private (self);
-  const gchar *subtitle = gtk_label_get_label (priv->subtitle_label);
+  const gchar *subtitle = gtk_label_get_label (self->subtitle_label);
 
-  gtk_widget_set_visible (GTK_WIDGET (priv->subtitle_label), subtitle && subtitle[0]);
+  gtk_widget_set_visible (GTK_WIDGET (self->subtitle_label), subtitle && subtitle[0]);
 
   gtk_widget_queue_resize (GTK_WIDGET (self));
 }
@@ -115,14 +118,13 @@ count_children_cb (GtkWidget *widget,
 static void
 update_view_switcher_visible (HdyViewSwitcherTitle *self)
 {
-  HdyViewSwitcherTitlePrivate *priv = hdy_view_switcher_title_get_instance_private (self);
-  GtkStack *stack = hdy_view_switcher_get_stack (priv->view_switcher);
+  GtkStack *stack = hdy_view_switcher_get_stack (self->view_switcher);
   gint count = 0;
 
-  if (priv->view_switcher_enabled && stack)
+  if (self->view_switcher_enabled && stack)
     gtk_container_foreach (GTK_CONTAINER (stack), (GtkCallback) count_children_cb, &count);
 
-  hdy_squeezer_set_child_enabled (priv->squeezer, GTK_WIDGET (priv->view_switcher), count > 1);
+  hdy_squeezer_set_child_enabled (self->squeezer, GTK_WIDGET (self->view_switcher), count > 1);
 }
 
 static void
@@ -143,9 +145,6 @@ hdy_view_switcher_title_get_property (GObject    *object,
   case PROP_POLICY:
     g_value_set_enum (value, hdy_view_switcher_title_get_policy (self));
     break;
-  case PROP_ICON_SIZE:
-    g_value_set_int (value, hdy_view_switcher_title_get_icon_size (self));
-    break;
   case PROP_STACK:
     g_value_set_object (value, hdy_view_switcher_title_get_stack (self));
     break;
@@ -179,9 +178,6 @@ hdy_view_switcher_title_set_property (GObject      *object,
   case PROP_POLICY:
     hdy_view_switcher_title_set_policy (self, g_value_get_enum (value));
     break;
-  case PROP_ICON_SIZE:
-    hdy_view_switcher_title_set_icon_size (self, g_value_get_int (value));
-    break;
   case PROP_STACK:
     hdy_view_switcher_title_set_stack (self, g_value_get_object (value));
     break;
@@ -203,10 +199,9 @@ hdy_view_switcher_title_set_property (GObject      *object,
 static void
 hdy_view_switcher_title_dispose (GObject *object) {
   HdyViewSwitcherTitle *self = (HdyViewSwitcherTitle *)object;
-  HdyViewSwitcherTitlePrivate *priv = hdy_view_switcher_title_get_instance_private (self);
 
-  if (priv->view_switcher) {
-    GtkStack *stack = hdy_view_switcher_get_stack (priv->view_switcher);
+  if (self->view_switcher) {
+    GtkStack *stack = hdy_view_switcher_get_stack (self->view_switcher);
 
     if (stack)
       g_signal_handlers_disconnect_by_func (stack, G_CALLBACK (update_view_switcher_visible), self);
@@ -226,10 +221,9 @@ hdy_view_switcher_title_class_init (HdyViewSwitcherTitleClass *klass)
   object_class->set_property = hdy_view_switcher_title_set_property;
 
   /**
-   * HdyViewSwitcherTitle:policy:
+   * HdyViewSwitcherTitle:policy: (attributes org.gtk.Property.get=hdy_view_switcher_title_get_policy org.gtk.Property.set=hdy_view_switcher_title_set_policy)
    *
-   * The #HdyViewSwitcherPolicy the #HdyViewSwitcher should use to determine
-   * which mode to use.
+   * The policy used to determine which mode to use.
    *
    * Since: 1.0
    */
@@ -237,28 +231,13 @@ hdy_view_switcher_title_class_init (HdyViewSwitcherTitleClass *klass)
     g_param_spec_enum ("policy",
                        _("Policy"),
                        _("The policy to determine the mode to use"),
-                       HDY_TYPE_VIEW_SWITCHER_POLICY, HDY_VIEW_SWITCHER_POLICY_WIDE,
+                       HDY_TYPE_VIEW_SWITCHER_POLICY, HDY_VIEW_SWITCHER_POLICY_AUTO,
                        G_PARAM_EXPLICIT_NOTIFY | G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS);
 
   /**
-   * HdyViewSwitcherTitle:icon-size:
+   * HdyViewSwitcherTitle:stack: (attributes org.gtk.Property.get=hdy_view_switcher_title_get_stack org.gtk.Property.set=hdy_view_switcher_title_set_stack)
    *
-   * Use the "icon-size" property to hint the icons to use, you almost certainly
-   * want to leave this as %GTK_ICON_SIZE_BUTTON.
-   *
-   * Since: 1.0
-   */
-  props[PROP_ICON_SIZE] =
-    g_param_spec_int ("icon-size",
-                      _("Icon Size"),
-                      _("Symbolic size to use for named icon"),
-                      0, G_MAXINT, GTK_ICON_SIZE_BUTTON,
-                      G_PARAM_EXPLICIT_NOTIFY | G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS);
-
-  /**
-   * HdyViewSwitcherTitle:stack:
-   *
-   * The #GtkStack the #HdyViewSwitcher controls.
+   * The [class@Gtk.Stack] the [class@ViewSwitcher] controls.
    *
    * Since: 1.0
    */
@@ -270,9 +249,12 @@ hdy_view_switcher_title_class_init (HdyViewSwitcherTitleClass *klass)
                          G_PARAM_EXPLICIT_NOTIFY | G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS);
 
   /**
-   * HdyViewSwitcherTitle:title:
+   * HdyViewSwitcherTitle:title: (attributes org.gtk.Property.get=hdy_view_switcher_title_get_title org.gtk.Property.set=hdy_view_switcher_title_set_title)
    *
-   * The title of the #HdyViewSwitcher.
+   * The title of the [class@ViewSwitcher].
+   *
+   * The title should give a user additional details. A good title should not
+   * include the application name.
    *
    * Since: 1.0
    */
@@ -284,9 +266,11 @@ hdy_view_switcher_title_class_init (HdyViewSwitcherTitleClass *klass)
                          G_PARAM_EXPLICIT_NOTIFY | G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS);
 
   /**
-   * HdyViewSwitcherTitle:subtitle:
+   * HdyViewSwitcherTitle:subtitle: (attributes org.gtk.Property.get=hdy_view_switcher_title_get_subtitle org.gtk.Property.set=hdy_view_switcher_title_set_subtitle)
    *
-   * The subtitle of the #HdyViewSwitcher.
+   * The subtitle of the [class@ViewSwitcher].
+   *
+   * The subtitle should give a user additional details.
    *
    * Since: 1.0
    */
@@ -298,10 +282,17 @@ hdy_view_switcher_title_class_init (HdyViewSwitcherTitleClass *klass)
                          G_PARAM_EXPLICIT_NOTIFY | G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS);
 
   /**
-   * HdyViewSwitcherTitle:view-switcher-enabled:
+   * HdyViewSwitcherTitle:view-switcher-enabled: (attributes org.gtk.Property.get=hdy_view_switcher_title_get_view_switcher_enabled org.gtk.Property.set=hdy_view_switcher_title_set_view_switcher_enabled)
    *
    * Whether the bar should be revealed or hidden.
    *
+   * If it is disabled, the title will be displayed instead. This allows to
+   * programmatically hide the view switcher even if it fits in the available
+   * space.
+   *
+   * This can be used e.g. to ensure the view switcher is hidden below a certain
+   * window width, or any other constraint you find suitable.
+   *
    * Since: 1.0
    */
   props[PROP_VIEW_SWITCHER_ENABLED] =
@@ -312,7 +303,7 @@ hdy_view_switcher_title_class_init (HdyViewSwitcherTitleClass *klass)
                          G_PARAM_EXPLICIT_NOTIFY | G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS);
 
   /**
-   * HdyViewSwitcherTitle:title-visible:
+   * HdyViewSwitcherTitle:title-visible: (attributes org.gtk.Property.get=hdy_view_switcher_title_get_title_visible)
    *
    * Whether the bar should be revealed or hidden.
    *
@@ -331,25 +322,21 @@ hdy_view_switcher_title_class_init (HdyViewSwitcherTitleClass *klass)
 
   gtk_widget_class_set_template_from_resource (widget_class,
                                                "/sm/puri/handy/ui/hdy-view-switcher-title.ui");
-  gtk_widget_class_bind_template_child_private (widget_class, HdyViewSwitcherTitle, squeezer);
-  gtk_widget_class_bind_template_child_private (widget_class, HdyViewSwitcherTitle, subtitle_label);
-  gtk_widget_class_bind_template_child_private (widget_class, HdyViewSwitcherTitle, title_box);
-  gtk_widget_class_bind_template_child_private (widget_class, HdyViewSwitcherTitle, title_label);
-  gtk_widget_class_bind_template_child_private (widget_class, HdyViewSwitcherTitle, view_switcher);
+  gtk_widget_class_bind_template_child (widget_class, HdyViewSwitcherTitle, squeezer);
+  gtk_widget_class_bind_template_child (widget_class, HdyViewSwitcherTitle, subtitle_label);
+  gtk_widget_class_bind_template_child (widget_class, HdyViewSwitcherTitle, title_box);
+  gtk_widget_class_bind_template_child (widget_class, HdyViewSwitcherTitle, title_label);
+  gtk_widget_class_bind_template_child (widget_class, HdyViewSwitcherTitle, view_switcher);
   gtk_widget_class_bind_template_callback (widget_class, notify_squeezer_visible_child_cb);
 }
 
 static void
 hdy_view_switcher_title_init (HdyViewSwitcherTitle *self)
 {
-  HdyViewSwitcherTitlePrivate *priv;
-
-  priv = hdy_view_switcher_title_get_instance_private (self);
-
   /* This must be initialized before the template so the embedded view switcher
    * can pick up the correct default value.
    */
-  priv->view_switcher_enabled = TRUE;
+  self->view_switcher_enabled = TRUE;
 
   gtk_widget_init_template (GTK_WIDGET (self));
 
@@ -360,9 +347,9 @@ hdy_view_switcher_title_init (HdyViewSwitcherTitle *self)
 /**
  * hdy_view_switcher_title_new:
  *
- * Creates a new #HdyViewSwitcherTitle widget.
+ * Creates a new `HdyViewSwitcherTitle`.
  *
- * Returns: a new #HdyViewSwitcherTitle
+ * Returns: the newly created `HdyViewSwitcherTitle`
  *
  * Since: 1.0
  */
@@ -373,8 +360,8 @@ hdy_view_switcher_title_new (void)
 }
 
 /**
- * hdy_view_switcher_title_get_policy:
- * @self: a #HdyViewSwitcherTitle
+ * hdy_view_switcher_title_get_policy: (attributes org.gtk.Method.get_property=policy)
+ * @self: a view switcher title
  *
  * Gets the policy of @self.
  *
@@ -385,18 +372,14 @@ hdy_view_switcher_title_new (void)
 HdyViewSwitcherPolicy
 hdy_view_switcher_title_get_policy (HdyViewSwitcherTitle *self)
 {
-  HdyViewSwitcherTitlePrivate *priv;
-
   g_return_val_if_fail (HDY_IS_VIEW_SWITCHER_TITLE (self), HDY_VIEW_SWITCHER_POLICY_NARROW);
 
-  priv = hdy_view_switcher_title_get_instance_private (self);
-
-  return hdy_view_switcher_get_policy (priv->view_switcher);
+  return hdy_view_switcher_get_policy (self->view_switcher);
 }
 
 /**
- * hdy_view_switcher_title_set_policy:
- * @self: a #HdyViewSwitcherTitle
+ * hdy_view_switcher_title_set_policy: (attributes org.gtk.Method.set_property=policy)
+ * @self: a view switcher title
  * @policy: the new policy
  *
  * Sets the policy of @self.
@@ -407,16 +390,12 @@ void
 hdy_view_switcher_title_set_policy (HdyViewSwitcherTitle  *self,
                                     HdyViewSwitcherPolicy  policy)
 {
-  HdyViewSwitcherTitlePrivate *priv;
-
   g_return_if_fail (HDY_IS_VIEW_SWITCHER_TITLE (self));
 
-  priv = hdy_view_switcher_title_get_instance_private (self);
-
-  if (hdy_view_switcher_get_policy (priv->view_switcher) == policy)
+  if (hdy_view_switcher_get_policy (self->view_switcher) == policy)
     return;
 
-  hdy_view_switcher_set_policy (priv->view_switcher, policy);
+  hdy_view_switcher_set_policy (self->view_switcher, policy);
 
   g_object_notify_by_pspec (G_OBJECT (self), props[PROP_POLICY]);
 
@@ -424,82 +403,29 @@ hdy_view_switcher_title_set_policy (HdyViewSwitcherTitle  *self,
 }
 
 /**
- * hdy_view_switcher_title_get_icon_size:
- * @self: a #HdyViewSwitcherTitle
+ * hdy_view_switcher_title_get_stack: (attributes org.gtk.Method.get_property=stack)
+ * @self: a view switcher title
  *
- * Get the icon size of the images used in the #HdyViewSwitcher.
+ * Gets the stack controlled by @self.
  *
- * Returns: the icon size of the images
- *
- * Since: 1.0
- */
-GtkIconSize
-hdy_view_switcher_title_get_icon_size (HdyViewSwitcherTitle *self)
-{
-  HdyViewSwitcherTitlePrivate *priv;
-
-  g_return_val_if_fail (HDY_IS_VIEW_SWITCHER_TITLE (self), GTK_ICON_SIZE_BUTTON);
-
-  priv = hdy_view_switcher_title_get_instance_private (self);
-
-  return hdy_view_switcher_get_icon_size (priv->view_switcher);
-}
-
-/**
- * hdy_view_switcher_title_set_icon_size:
- * @self: a #HdyViewSwitcherTitle
- * @icon_size: the new icon size
- *
- * Change the icon size hint for the icons in a #HdyViewSwitcher.
- *
- * Since: 1.0
- */
-void
-hdy_view_switcher_title_set_icon_size (HdyViewSwitcherTitle *self,
-                                       GtkIconSize           icon_size)
-{
-  HdyViewSwitcherTitlePrivate *priv;
-
-  g_return_if_fail (HDY_IS_VIEW_SWITCHER_TITLE (self));
-
-  priv = hdy_view_switcher_title_get_instance_private (self);
-
-  if (hdy_view_switcher_get_icon_size (priv->view_switcher) == icon_size)
-    return;
-
-  hdy_view_switcher_set_icon_size (priv->view_switcher, icon_size);
-
-  g_object_notify_by_pspec (G_OBJECT (self), props[PROP_ICON_SIZE]);
-}
-
-/**
- * hdy_view_switcher_title_get_stack:
- * @self: a #HdyViewSwitcherTitle
- *
- * Get the #GtkStack being controlled by the #HdyViewSwitcher.
- *
- * Returns: (nullable) (transfer none): the #GtkStack, or %NULL if none has been set
+ * Returns: (nullable) (transfer none): the stack
  *
  * Since: 1.0
  */
 GtkStack *
 hdy_view_switcher_title_get_stack (HdyViewSwitcherTitle *self)
 {
-  HdyViewSwitcherTitlePrivate *priv;
-
   g_return_val_if_fail (HDY_IS_VIEW_SWITCHER_TITLE (self), NULL);
 
-  priv = hdy_view_switcher_title_get_instance_private (self);
-
-  return hdy_view_switcher_get_stack (priv->view_switcher);
+  return hdy_view_switcher_get_stack (self->view_switcher);
 }
 
 /**
- * hdy_view_switcher_title_set_stack:
- * @self: a #HdyViewSwitcherTitle
- * @stack: (nullable): a #GtkStack
+ * hdy_view_switcher_title_set_stack: (attributes org.gtk.Method.set_property=policy)
+ * @self: a view switcher title
+ * @stack: (nullable): a stack
  *
- * Sets the #GtkStack to control.
+ * Sets the [class@Gtk.Stack] to control.
  *
  * Since: 1.0
  */
@@ -507,14 +433,12 @@ void
 hdy_view_switcher_title_set_stack (HdyViewSwitcherTitle *self,
                                    GtkStack             *stack)
 {
-  HdyViewSwitcherTitlePrivate *priv;
   GtkStack *previous_stack;
 
   g_return_if_fail (HDY_IS_VIEW_SWITCHER_TITLE (self));
   g_return_if_fail (stack == NULL || GTK_IS_STACK (stack));
 
-  priv = hdy_view_switcher_title_get_instance_private (self);
-  previous_stack = hdy_view_switcher_get_stack (priv->view_switcher);
+  previous_stack = hdy_view_switcher_get_stack (self->view_switcher);
 
   if (previous_stack == stack)
     return;
@@ -522,7 +446,7 @@ hdy_view_switcher_title_set_stack (HdyViewSwitcherTitle *self,
   if (previous_stack)
     g_signal_handlers_disconnect_by_func (previous_stack, G_CALLBACK (update_view_switcher_visible), self);
 
-  hdy_view_switcher_set_stack (priv->view_switcher, stack);
+  hdy_view_switcher_set_stack (self->view_switcher, stack);
 
   if (stack) {
     g_signal_connect_swapped (stack, "add", G_CALLBACK (update_view_switcher_visible), self);
@@ -535,34 +459,29 @@ hdy_view_switcher_title_set_stack (HdyViewSwitcherTitle *self,
 }
 
 /**
- * hdy_view_switcher_title_get_title:
- * @self: a #HdyViewSwitcherTitle
+ * hdy_view_switcher_title_get_title: (attributes org.gtk.Method.get_property=title)
+ * @self: a view switcher title
  *
- * Gets the title of @self. See hdy_view_switcher_title_set_title().
+ * Gets the title of @self.
  *
- * Returns: (transfer none) (nullable): the title of @self, or %NULL.
+ * Returns: (transfer none) (nullable): the title of @self
  *
  * Since: 1.0
  */
 const gchar *
 hdy_view_switcher_title_get_title (HdyViewSwitcherTitle *self)
 {
-  HdyViewSwitcherTitlePrivate *priv;
-
   g_return_val_if_fail (HDY_IS_VIEW_SWITCHER_TITLE (self), NULL);
 
-  priv = hdy_view_switcher_title_get_instance_private (self);
-
-  return gtk_label_get_label (priv->title_label);
+  return gtk_label_get_label (self->title_label);
 }
 
 /**
- * hdy_view_switcher_title_set_title:
- * @self: a #HdyViewSwitcherTitle
- * @title: (allow-none): a title, or %NULL
+ * hdy_view_switcher_title_set_title: (attributes org.gtk.Method.set_property=title)
+ * @self: a view switcher title
+ * @title: (nullable): a title
  *
- * Sets the title of @self. The title should give a user additional details. A
- * good title should not include the application name.
+ * Sets the title of @self.
  *
  * Since: 1.0
  */
@@ -570,50 +489,41 @@ void
 hdy_view_switcher_title_set_title (HdyViewSwitcherTitle *self,
                                    const gchar          *title)
 {
-  HdyViewSwitcherTitlePrivate *priv;
-
   g_return_if_fail (HDY_IS_VIEW_SWITCHER_TITLE (self));
 
-  priv = hdy_view_switcher_title_get_instance_private (self);
-
-  if (g_strcmp0 (gtk_label_get_label (priv->title_label), title) == 0)
+  if (g_strcmp0 (gtk_label_get_label (self->title_label), title) == 0)
     return;
 
-  gtk_label_set_label (priv->title_label, title);
-  gtk_widget_set_visible (GTK_WIDGET (priv->title_label), title && title[0]);
+  gtk_label_set_label (self->title_label, title);
+  gtk_widget_set_visible (GTK_WIDGET (self->title_label), title && title[0]);
 
   g_object_notify_by_pspec (G_OBJECT (self), props[PROP_TITLE]);
 }
 
 /**
- * hdy_view_switcher_title_get_subtitle:
- * @self: a #HdyViewSwitcherTitle
+ * hdy_view_switcher_title_get_subtitle: (attributes org.gtk.Method.get_property=subtitle)
+ * @self: a view switcher title
  *
- * Gets the subtitle of @self. See hdy_view_switcher_title_set_subtitle().
+ * Gets the subtitle of @self.
  *
- * Returns: (transfer none) (nullable): the subtitle of @self, or %NULL.
+ * Returns: (transfer none) (nullable): the subtitle of @self
  *
  * Since: 1.0
  */
 const gchar *
 hdy_view_switcher_title_get_subtitle (HdyViewSwitcherTitle *self)
 {
-  HdyViewSwitcherTitlePrivate *priv;
-
   g_return_val_if_fail (HDY_IS_VIEW_SWITCHER_TITLE (self), NULL);
 
-  priv = hdy_view_switcher_title_get_instance_private (self);
-
-  return gtk_label_get_label (priv->subtitle_label);
+  return gtk_label_get_label (self->subtitle_label);
 }
 
 /**
- * hdy_view_switcher_title_set_subtitle:
- * @self: a #HdyViewSwitcherTitle
- * @subtitle: (allow-none): a subtitle, or %NULL
+ * hdy_view_switcher_title_set_subtitle: (attributes org.gtk.Method.set_property=subtitle)
+ * @self: a view switcher title
+ * @subtitle: (nullable): a subtitle
  *
- * Sets the subtitle of @self. The subtitle should give a user additional
- * details.
+ * Sets the subtitle of @self.
  *
  * Since: 1.0
  */
@@ -621,56 +531,41 @@ void
 hdy_view_switcher_title_set_subtitle (HdyViewSwitcherTitle *self,
                                       const gchar          *subtitle)
 {
-  HdyViewSwitcherTitlePrivate *priv;
-
   g_return_if_fail (HDY_IS_VIEW_SWITCHER_TITLE (self));
 
-  priv = hdy_view_switcher_title_get_instance_private (self);
-
-  if (g_strcmp0 (gtk_label_get_label (priv->subtitle_label), subtitle) == 0)
+  if (g_strcmp0 (gtk_label_get_label (self->subtitle_label), subtitle) == 0)
     return;
 
-  gtk_label_set_label (priv->subtitle_label, subtitle);
+  gtk_label_set_label (self->subtitle_label, subtitle);
   update_subtitle_label (self);
 
   g_object_notify_by_pspec (G_OBJECT (self), props[PROP_SUBTITLE]);
 }
 
 /**
- * hdy_view_switcher_title_get_view_switcher_enabled:
- * @self: a #HdyViewSwitcherTitle
+ * hdy_view_switcher_title_get_view_switcher_enabled: (attributes org.gtk.Method.get_property=view-switcher-enabled)
+ * @self: a view switcher title
  *
  * Gets whether @self's view switcher is enabled.
  *
- * See hdy_view_switcher_title_set_view_switcher_enabled().
- *
- * Returns: %TRUE if the view switcher is enabled, %FALSE otherwise.
+ * Returns: whether the view switcher is enabled
  *
  * Since: 1.0
  */
 gboolean
 hdy_view_switcher_title_get_view_switcher_enabled (HdyViewSwitcherTitle *self)
 {
-  HdyViewSwitcherTitlePrivate *priv;
-
   g_return_val_if_fail (HDY_IS_VIEW_SWITCHER_TITLE (self), FALSE);
 
-  priv = hdy_view_switcher_title_get_instance_private (self);
-
-  return priv->view_switcher_enabled;
+  return self->view_switcher_enabled;
 }
 
 /**
- * hdy_view_switcher_title_set_view_switcher_enabled:
- * @self: a #HdyViewSwitcherTitle
- * @enabled: %TRUE to enable the view switcher, %FALSE to disable it
+ * hdy_view_switcher_title_set_view_switcher_enabled: (attributes org.gtk.Method.set_property=view-switcher-enabled)
+ * @self: a view switcher title
+ * @enabled: `TRUE` to enable the view switcher, `FALSE` to disable it
  *
- * Make @self enable or disable its view switcher. If it is disabled, the title
- * will be displayed instead. This allows to programmatically and prematurely
- * hide the view switcher of @self even if it fits in the available space.
- *
- * This can be used e.g. to ensure the view switcher is hidden below a certain
- * window width, or any other constraint you find suitable.
+ * Sets whether @self's view switcher is enabled.
  *
  * Since: 1.0
  */
@@ -678,41 +573,33 @@ void
 hdy_view_switcher_title_set_view_switcher_enabled (HdyViewSwitcherTitle *self,
                                                    gboolean              enabled)
 {
-  HdyViewSwitcherTitlePrivate *priv;
-
   g_return_if_fail (HDY_IS_VIEW_SWITCHER_TITLE (self));
 
-  priv = hdy_view_switcher_title_get_instance_private (self);
-
   enabled = !!enabled;
 
-  if (priv->view_switcher_enabled == enabled)
+  if (self->view_switcher_enabled == enabled)
     return;
 
-  priv->view_switcher_enabled = enabled;
+  self->view_switcher_enabled = enabled;
   update_view_switcher_visible (self);
 
   g_object_notify_by_pspec (G_OBJECT (self), props[PROP_VIEW_SWITCHER_ENABLED]);
 }
 
 /**
- * hdy_view_switcher_title_get_title_visible:
- * @self: a #HdyViewSwitcherTitle
+ * hdy_view_switcher_title_get_title_visible: (attributes org.gtk.Method.get_property=title-visible)
+ * @self: a view switcher title
  *
- * Get whether the title label of @self is visible.
+ * Gets whether the title of @self is currently visible.
  *
- * Returns: %TRUE if the title label of @self is visible, %FALSE if not.
+ * Returns: whether the title of @self is currently visible
  *
  * Since: 1.0
  */
 gboolean
 hdy_view_switcher_title_get_title_visible (HdyViewSwitcherTitle *self)
 {
-  HdyViewSwitcherTitlePrivate *priv;
-
   g_return_val_if_fail (HDY_IS_VIEW_SWITCHER_TITLE (self), FALSE);
 
-  priv = hdy_view_switcher_title_get_instance_private (self);
-
-  return hdy_squeezer_get_visible_child (priv->squeezer) == (GtkWidget *) priv->title_box;
+  return hdy_squeezer_get_visible_child (self->squeezer) == (GtkWidget *) self->title_box;
 }
