@@ -1,10 +1,9 @@
 /*
  * Copyright (C) 2018 Purism SPC
  *
- * SPDX-License-Identifier: LGPL-2.1+
+ * SPDX-License-Identifier: LGPL-2.1-or-later
  */
 
-#define HANDY_USE_UNSTABLE_API
 #include <handy.h>
 
 gint activated;
@@ -48,21 +47,6 @@ test_hdy_action_row_add_prefix (void)
 }
 
 
-static void
-test_hdy_action_row_title (void)
-{
-  g_autoptr (HdyActionRow) row = NULL;
-
-  row = g_object_ref_sink (HDY_ACTION_ROW (hdy_action_row_new ()));
-  g_assert_nonnull (row);
-
-  g_assert_cmpstr (hdy_action_row_get_title (row), ==, "");
-
-  hdy_action_row_set_title (row, "Dummy title");
-  g_assert_cmpstr (hdy_action_row_get_title (row), ==, "Dummy title");
-}
-
-
 static void
 test_hdy_action_row_subtitle (void)
 {
@@ -94,7 +78,7 @@ test_hdy_action_row_icon_name (void)
 
 
 static void
-test_hdy_action_row_use_undeline (void)
+test_hdy_action_row_use_underline (void)
 {
   g_autoptr (HdyActionRow) row = NULL;
 
@@ -111,6 +95,48 @@ test_hdy_action_row_use_undeline (void)
 }
 
 
+static void
+test_hdy_action_row_title_lines (void)
+{
+  g_autoptr (HdyActionRow) row = NULL;
+
+  row = g_object_ref_sink (HDY_ACTION_ROW (hdy_action_row_new ()));
+  g_assert_nonnull (row);
+
+  g_assert_cmpint (hdy_action_row_get_title_lines (row), ==, 1);
+
+  g_test_expect_message (HDY_LOG_DOMAIN, G_LOG_LEVEL_CRITICAL, "hdy_action_row_set_title_lines: assertion 'title_lines >= 0' failed");
+  hdy_action_row_set_title_lines (row, -1);
+  g_test_assert_expected_messages ();
+
+  g_assert_cmpint (hdy_action_row_get_title_lines (row), ==, 1);
+
+  hdy_action_row_set_title_lines (row, 0);
+  g_assert_cmpint (hdy_action_row_get_title_lines (row), ==, 0);
+}
+
+
+static void
+test_hdy_action_row_subtitle_lines (void)
+{
+  g_autoptr (HdyActionRow) row = NULL;
+
+  row = g_object_ref_sink (HDY_ACTION_ROW (hdy_action_row_new ()));
+  g_assert_nonnull (row);
+
+  g_assert_cmpint (hdy_action_row_get_subtitle_lines (row), ==, 1);
+
+  g_test_expect_message (HDY_LOG_DOMAIN, G_LOG_LEVEL_CRITICAL, "hdy_action_row_set_subtitle_lines: assertion 'subtitle_lines >= 0' failed");
+  hdy_action_row_set_subtitle_lines (row, -1);
+  g_test_assert_expected_messages ();
+
+  g_assert_cmpint (hdy_action_row_get_subtitle_lines (row), ==, 1);
+
+  hdy_action_row_set_subtitle_lines (row, 0);
+  g_assert_cmpint (hdy_action_row_get_subtitle_lines (row), ==, 0);
+}
+
+
 static void
 test_hdy_action_row_activate (void)
 {
@@ -136,10 +162,11 @@ main (gint argc,
 
   g_test_add_func("/Handy/ActionRow/add", test_hdy_action_row_add);
   g_test_add_func("/Handy/ActionRow/add_prefix", test_hdy_action_row_add_prefix);
-  g_test_add_func("/Handy/ActionRow/title", test_hdy_action_row_title);
   g_test_add_func("/Handy/ActionRow/subtitle", test_hdy_action_row_subtitle);
   g_test_add_func("/Handy/ActionRow/icon_name", test_hdy_action_row_icon_name);
-  g_test_add_func("/Handy/ActionRow/use_underline", test_hdy_action_row_use_undeline);
+  g_test_add_func("/Handy/ActionRow/use_underline", test_hdy_action_row_use_underline);
+  g_test_add_func("/Handy/ActionRow/title_lines", test_hdy_action_row_title_lines);
+  g_test_add_func("/Handy/ActionRow/subtitle_lines", test_hdy_action_row_subtitle_lines);
   g_test_add_func("/Handy/ActionRow/activate", test_hdy_action_row_activate);
 
   return g_test_run();
